# 具体例

## 日付表現 1

```
【2021年1月21日】大統領宣誓を行うジョー・バイデン。 20日、アメリカ合衆国の首都ワシントンD.C.において、大統領就任式が行われた。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="2021-01-21" text="2021年1月21日">,
<TIMEX3 tid="t1" type="DATE" value="XXXX-XX-20" text="20日">
```

[バイデン米大統領の就任式が開催される \- ウィキニュース](https://ja.wikinews.org/wiki/%E3%83%90%E3%82%A4%E3%83%87%E3%83%B3%E7%B1%B3%E5%A4%A7%E7%B5%B1%E9%A0%98%E3%81%AE%E5%B0%B1%E4%BB%BB%E5%BC%8F%E3%81%8C%E9%96%8B%E5%82%AC%E3%81%95%E3%82%8C%E3%82%8B)

!!! Tips
    文中の`20日`のように、たとえ前後の文脈から日付が推定できたとしても、ja-timexでは表層表現の情報のみを利用します。

---

## 日付表現 2

```
気象庁が大雪とその被害について命名したのは1963年の「昭和38年1月豪雪」（三八豪雪）以外に例が無く、43年ぶり史上二度目の命名となった。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="1963-XX-XX" text="1963年">
<TIMEX3 tid="t1" type="DATE" value="1963-01-XX" text="昭和38年1月">
<TIMEX3 tid="t2" type="DURATION" value="P43Y" text="43年ぶり">
```

[今冬の大雪は『平成18年豪雪』、死者数は戦後2番目に \- ウィキニュース](https://ja.wikinews.org/wiki/%E4%BB%8A%E5%86%AC%E3%81%AE%E5%A4%A7%E9%9B%AA%E3%81%AF%E3%80%8E%E5%B9%B3%E6%88%9018%E5%B9%B4%E8%B1%AA%E9%9B%AA%E3%80%8F%E3%80%81%E6%AD%BB%E8%80%85%E6%95%B0%E3%81%AF%E6%88%A6%E5%BE%8C2%E7%95%AA%E7%9B%AE%E3%81%AB)


!!! Tips
    `昭和`といった和暦は、`@value`の値では西暦に変換されます。

---

## 日付表現 3

```
アルプス山脈の山々に囲まれた深い谷の中にあり、毎年11月中旬から2月初めまでの83日間にわたっては山の陰となって日中でも太陽の光が当たらない。
```

```xml
<TIMEX3 tid="t0" type="SET" value="P1Y" quant="EACH" text="毎年">
<TIMEX3 tid="t1" type="DATE" value="XXXX-11-XX" mod="MID" text="11月中旬">
<TIMEX3 tid="t2" type="DATE" value="XXXX-02-XX" mod="START" text="2月初め">
<TIMEX3 tid="t3" type="DURATION" value="P83D" text="83日間">
```

[陽の当たらない山陰の村に光を─イタリアで巨大鏡設置 \- ウィキニュース](https://ja.wikinews.org/wiki/%E9%99%BD%E3%81%AE%E5%BD%93%E3%81%9F%E3%82%89%E3%81%AA%E3%81%84%E5%B1%B1%E9%99%B0%E3%81%AE%E6%9D%91%E3%81%AB%E5%85%89%E3%82%92%E2%94%80%E3%82%A4%E3%82%BF%E3%83%AA%E3%82%A2%E3%81%A7%E5%B7%A8%E5%A4%A7%E9%8F%A1%E8%A8%AD%E7%BD%AE)


!!! Tips
    `11月中旬`のように日付に付加情報が付いている場合は、`@value=XXXX-11-XX`のように月の値だけが入り、付加情報は`@mod=MID`のように表現されます。

---

## 日付表現 4

```
高松塚古墳は7世紀末から8世紀はじめにかけて造られたと見られる古墳で、雨水の浸入やカビの発生などにより石室内の壁画の劣化が問題になっている。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="06XX" mod="END" text="7世紀末">
<TIMEX3 tid="t1" type="DATE" value="07XX" mod="START" text="8世紀はじめ">
```

[高松塚古墳のカビ拡大、「飛鳥美人」にも被害 \- ウィキニュース](https://ja.wikinews.org/wiki/%E9%AB%98%E6%9D%BE%E5%A1%9A%E5%8F%A4%E5%A2%B3%E3%81%AE%E3%82%AB%E3%83%93%E6%8B%A1%E5%A4%A7%E3%80%81%E3%80%8C%E9%A3%9B%E9%B3%A5%E7%BE%8E%E4%BA%BA%E3%80%8D%E3%81%AB%E3%82%82%E8%A2%AB%E5%AE%B3)


!!! Tips
    世紀という表現は年単位での幅を持つため、年の下2桁を`XX`として表現します。例えば、7世紀は西暦601年から西暦700年までの間を指すため、`06XX`と表現します。

---

## 時刻表現 1

```
気象庁によれば、大型で非常に強い台風第13号 「タリム」は31日午後10時45分（日本時間、UTC+9）現在、台湾の東海上にあって、西北西に進んでいる。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="XXXX-XX-31" text="31日">
<TIMEX3 tid="t1" type="TIME" value="T22-45-XX" text="午後10時45分">
```

[台風13号、先島諸島から台湾へ−14号も沖縄に向かう \- ウィキニュース](https://ja.wikinews.org/wiki/%E5%8F%B0%E9%A2%A813%E5%8F%B7%E3%80%81%E5%85%88%E5%B3%B6%E8%AB%B8%E5%B3%B6%E3%81%8B%E3%82%89%E5%8F%B0%E6%B9%BE%E3%81%B8%E2%88%9214%E5%8F%B7%E3%82%82%E6%B2%96%E7%B8%84%E3%81%AB%E5%90%91%E3%81%8B%E3%81%86)

!!! Tips
    `午前`、`午後`などが付く12時間表記は、24時間表記に変換されます。

---

## 時刻表現 2

```
数学の試験時間は25日午後1時半から同3時半にかけてで、最も早い書き込みでは、午後1時37分に問題を掲載した上で、
```

```xml
<TIMEX3 tid="t0" type="DATE" value="XXXX-XX-25" text="25日">
<TIMEX3 tid="t1" type="TIME" value="T13-30-XX" text="午後1時半">
<TIMEX3 tid="t2" type="TIME" value="T03-30-XX" text="3時半">
<TIMEX3 tid="t3" type="TIME" value="T13-37-XX" text="午後1時37分">
```

[京都大学などで入試問題がネット掲示板に投稿される \- ウィキニュース](https://ja.wikinews.org/wiki/%E4%BA%AC%E9%83%BD%E5%A4%A7%E5%AD%A6%E3%81%AA%E3%81%A9%E3%81%A7%E5%85%A5%E8%A9%A6%E5%95%8F%E9%A1%8C%E3%81%8C%E3%83%8D%E3%83%83%E3%83%88%E6%8E%B2%E7%A4%BA%E6%9D%BF%E3%81%AB%E6%8A%95%E7%A8%BF%E3%81%95%E3%82%8C%E3%82%8B)

!!! Tips
    `午後1時半`のような`半`という表現は、`30分`と解釈します。

---

## 頻度集合表現

```
両リーグで異なっている試合競技方法の調整などの会議を週1回程度行い、10月末までに合意することを目指している
```

```xml
<TIMEX3 tid="t0" type="SET" value="P1W" freq="1X" text="週1回">
<TIMEX3 tid="t1" type="DATE" value="XXXX-10-XX" mod="END" text="10月末">
```

[日本のバスケットボールリーグ一本化へ向けた組織委員会発足 \- ウィキニュース](https://ja.wikinews.org/wiki/%E6%97%A5%E6%9C%AC%E3%81%AE%E3%83%90%E3%82%B9%E3%82%B1%E3%83%83%E3%83%88%E3%83%9C%E3%83%BC%E3%83%AB%E3%83%AA%E3%83%BC%E3%82%B0%E4%B8%80%E6%9C%AC%E5%8C%96%E3%81%B8%E5%90%91%E3%81%91%E3%81%9F%E7%B5%84%E7%B9%94%E5%A7%94%E5%93%A1%E4%BC%9A%E7%99%BA%E8%B6%B3)

!!! Tips
    `週1回`の`1回`は`@freq=1X`と表現します。

--- 

## 持続時間表現 1

```
奈良市環境清美部の男性職員 (42) が、2001年からの5年9カ月余りで8日しか出勤していないのにも関わらず、給与がほぼ満額支給されていたことが明らかになった。
```

```xml
<TIMEX3 tid="t0" type="DATE" value="2001-XX-XX" text="2001年">
<TIMEX3 tid="t1" type="DURATION" value="P5Y9M" text="5年9カ月">
<TIMEX3 tid="t2" type="DATE" value="XXXX-XX-08" text="8日">
```

[奈良市職員、5年間ほとんど出勤せず給与満額 \- ウィキニュース](https://ja.wikinews.org/wiki/%E5%A5%88%E8%89%AF%E5%B8%82%E8%81%B7%E5%93%A1%E3%80%815%E5%B9%B4%E9%96%93%E3%81%BB%E3%81%A8%E3%82%93%E3%81%A9%E5%87%BA%E5%8B%A4%E3%81%9B%E3%81%9A%E7%B5%A6%E4%B8%8E%E6%BA%80%E9%A1%8D)

!!! Tips
    `5年9カ月`といったように持続時間表現で複数の単位の組み合わせた表現の場合は、`@value`の値は`P5Y9M`のように複数の値が列挙されます。この際、日付表現を表す接頭辞`P`または時刻表現を表す`PT`は重複しません。

!!! Tips
    生物の年齢は、数値表現であって時間情報表現ではないので取得しません

---

## 持続時間表現 2

```
12月14日、日本の宇宙航空研究開発機構（JAXA）は、今月6日に地球に帰還した小惑星探査機「はやぶさ2」のカプセルから、リュウグウ由来とみられる砂粒状の粒子を採取することに成功したと発表した
```

```xml
<TIMEX3 tid="t0" type="DATE" value="XXXX-12-14" text="12月14日">,
<TIMEX3 tid="t1" type="DURATION" value="P0M" mod="NOW" text="今月">,
<TIMEX3 tid="t2" type="DATE" value="XXXX-XX-06" text="6日">
```

[はやぶさ2帰還カプセル 小惑星リュウグウ由来の粒子とガスを確認 \- ウィキニュース](https://ja.wikinews.org/wiki/%E3%81%AF%E3%82%84%E3%81%B6%E3%81%952%E5%B8%B0%E9%82%84%E3%82%AB%E3%83%97%E3%82%BB%E3%83%AB_%E5%B0%8F%E6%83%91%E6%98%9F%E3%83%AA%E3%83%A5%E3%82%A6%E3%82%B0%E3%82%A6%E7%94%B1%E6%9D%A5%E3%81%AE%E7%B2%92%E5%AD%90%E3%81%A8%E3%82%AC%E3%82%B9%E3%82%92%E7%A2%BA%E8%AA%8D)

!!! Warning
    `今月6日`は`今月`,`6日`に分割してタグ付けを行います。成澤\[2\]では1つのまとまりとして扱うように定義されていましたが、ja-timexでは分割します。
    
    その理由として、TIMEX3タグの定義上は日付表現として「いずれかの月」か「そもそも月の情報が不明」かを区別することができません。`XXXX-XX-06`という表記しかできず、今回の場合は`今月6日`のうちの`今月`の情報が表層表現から欠落してしまうため、情報の欠損を防ぐために分割しています。
    
    `今月`は、表層表現からではどの月かを推定することが不可能なため、日付表現とは扱わず持続時間表現として扱います。

!!! Tips
    持続時間表現としての`今月`は、`@value=P0M @mod=NOW`という2つの組み合わせで表現します。これは`先月`なら`@value=P1M @mod=BEFORE`、`来月`なら`@value=P1M @mod=AFTER`と表現することを踏まえたものです。

